@@ -61,7 +61,7 @@ from .type_defs import (
     TaxDocumentsTypeDef,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -95,7 +95,7 @@ class Exceptions:
 
 class SnowballClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html)
     """
 
@@ -111,7 +111,7 @@ class SnowballClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#can_paginate)
         """
 
@@ -119,7 +119,7 @@ class SnowballClient(BaseClient):
         """
         Cancels a cluster job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.cancel_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.cancel_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#cancel_cluster)
         """
 
@@ -127,7 +127,7 @@ class SnowballClient(BaseClient):
         """
         Cancels the specified job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#cancel_job)
         """
 
@@ -135,7 +135,7 @@ class SnowballClient(BaseClient):
         """
         Creates an address for a Snow device to be shipped to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_address)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.create_address)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_address)
         """
 
@@ -148,47 +148,47 @@ class SnowballClient(BaseClient):
         RoleARN: str,
         SnowballType: SnowballTypeType,
         ShippingOption: ShippingOptionType,
-        OnDeviceServiceConfiguration: "OnDeviceServiceConfigurationTypeDef" = None,
-        Description: str = None,
-        KmsKeyARN: str = None,
-        Notification: "NotificationTypeDef" = None,
-        ForwardingAddressId: str = None,
-        TaxDocuments: "TaxDocumentsTypeDef" = None,
-        RemoteManagement: RemoteManagementType = None
+        OnDeviceServiceConfiguration: "OnDeviceServiceConfigurationTypeDef" = ...,
+        Description: str = ...,
+        KmsKeyARN: str = ...,
+        Notification: "NotificationTypeDef" = ...,
+        ForwardingAddressId: str = ...,
+        TaxDocuments: "TaxDocumentsTypeDef" = ...,
+        RemoteManagement: RemoteManagementType = ...
     ) -> CreateClusterResultTypeDef:
         """
         Creates an empty cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.create_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_cluster)
         """
 
     def create_job(
         self,
         *,
-        JobType: JobTypeType = None,
-        Resources: "JobResourceTypeDef" = None,
-        OnDeviceServiceConfiguration: "OnDeviceServiceConfigurationTypeDef" = None,
-        Description: str = None,
-        AddressId: str = None,
-        KmsKeyARN: str = None,
-        RoleARN: str = None,
-        SnowballCapacityPreference: SnowballCapacityType = None,
-        ShippingOption: ShippingOptionType = None,
-        Notification: "NotificationTypeDef" = None,
-        ClusterId: str = None,
-        SnowballType: SnowballTypeType = None,
-        ForwardingAddressId: str = None,
-        TaxDocuments: "TaxDocumentsTypeDef" = None,
-        DeviceConfiguration: "DeviceConfigurationTypeDef" = None,
-        RemoteManagement: RemoteManagementType = None,
-        LongTermPricingId: str = None
+        JobType: JobTypeType = ...,
+        Resources: "JobResourceTypeDef" = ...,
+        OnDeviceServiceConfiguration: "OnDeviceServiceConfigurationTypeDef" = ...,
+        Description: str = ...,
+        AddressId: str = ...,
+        KmsKeyARN: str = ...,
+        RoleARN: str = ...,
+        SnowballCapacityPreference: SnowballCapacityType = ...,
+        ShippingOption: ShippingOptionType = ...,
+        Notification: "NotificationTypeDef" = ...,
+        ClusterId: str = ...,
+        SnowballType: SnowballTypeType = ...,
+        ForwardingAddressId: str = ...,
+        TaxDocuments: "TaxDocumentsTypeDef" = ...,
+        DeviceConfiguration: "DeviceConfigurationTypeDef" = ...,
+        RemoteManagement: RemoteManagementType = ...,
+        LongTermPricingId: str = ...
     ) -> CreateJobResultTypeDef:
         """
         Creates a job to import or export data between Amazon S3 and your on-premises
         data center.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.create_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_job)
         """
 
@@ -196,23 +196,23 @@ class SnowballClient(BaseClient):
         self,
         *,
         LongTermPricingType: LongTermPricingTypeType,
-        IsLongTermPricingAutoRenew: bool = None,
-        SnowballType: SnowballTypeType = None
+        IsLongTermPricingAutoRenew: bool = ...,
+        SnowballType: SnowballTypeType = ...
     ) -> CreateLongTermPricingResultTypeDef:
         """
         Creates a job with the long-term usage option for a device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_long_term_pricing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.create_long_term_pricing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_long_term_pricing)
         """
 
     def create_return_shipping_label(
-        self, *, JobId: str, ShippingOption: ShippingOptionType = None
+        self, *, JobId: str, ShippingOption: ShippingOptionType = ...
     ) -> CreateReturnShippingLabelResultTypeDef:
         """
         Creates a shipping label that will be used to return the Snow device to AWS.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.create_return_shipping_label)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.create_return_shipping_label)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#create_return_shipping_label)
         """
 
@@ -221,17 +221,17 @@ class SnowballClient(BaseClient):
         Takes an `AddressId` and returns specific details about that address in the form
         of an `Address` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_address)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.describe_address)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_address)
         """
 
     def describe_addresses(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeAddressesResultTypeDef:
         """
         Returns a specified number of `ADDRESS` objects.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_addresses)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.describe_addresses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_addresses)
         """
 
@@ -240,7 +240,7 @@ class SnowballClient(BaseClient):
         Returns information about a specific cluster including shipping information,
         cluster status, and other important metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.describe_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_cluster)
         """
 
@@ -249,7 +249,7 @@ class SnowballClient(BaseClient):
         Returns information about a specific job including shipping information, job
         status, and other important metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.describe_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_job)
         """
 
@@ -260,21 +260,21 @@ class SnowballClient(BaseClient):
         Information on the shipping label of a Snow device that is being returned to
         AWS.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.describe_return_shipping_label)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.describe_return_shipping_label)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#describe_return_shipping_label)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#generate_presigned_url)
         """
 
@@ -283,7 +283,7 @@ class SnowballClient(BaseClient):
         Returns a link to an Amazon S3 presigned URL for the manifest file associated
         with the specified `JobId` value.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.get_job_manifest)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.get_job_manifest)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#get_job_manifest)
         """
 
@@ -291,7 +291,7 @@ class SnowballClient(BaseClient):
         """
         Returns the `UnlockCode` code value for the specified job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.get_job_unlock_code)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.get_job_unlock_code)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#get_job_unlock_code)
         """
 
@@ -300,7 +300,7 @@ class SnowballClient(BaseClient):
         Returns information about the Snow Family service limit for your account, and
         also the number of Snow devices your account has in use.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.get_snowball_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.get_snowball_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#get_snowball_usage)
         """
 
@@ -309,57 +309,57 @@ class SnowballClient(BaseClient):
         Returns an Amazon S3 presigned URL for an update file associated with a
         specified `JobId` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.get_software_updates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.get_software_updates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#get_software_updates)
         """
 
     def list_cluster_jobs(
-        self, *, ClusterId: str, MaxResults: int = None, NextToken: str = None
+        self, *, ClusterId: str, MaxResults: int = ..., NextToken: str = ...
     ) -> ListClusterJobsResultTypeDef:
         """
         Returns an array of `JobListEntry` objects of the specified length.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_cluster_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.list_cluster_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_cluster_jobs)
         """
 
     def list_clusters(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListClustersResultTypeDef:
         """
         Returns an array of `ClusterListEntry` objects of the specified length.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.list_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_clusters)
         """
 
     def list_compatible_images(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListCompatibleImagesResultTypeDef:
         """
         This action returns a list of the different Amazon EC2 Amazon Machine Images
         (AMIs) that are owned by your AWS account that would be supported for use on a
         Snow device.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_compatible_images)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.list_compatible_images)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_compatible_images)
         """
 
-    def list_jobs(self, *, MaxResults: int = None, NextToken: str = None) -> ListJobsResultTypeDef:
+    def list_jobs(self, *, MaxResults: int = ..., NextToken: str = ...) -> ListJobsResultTypeDef:
         """
         Returns an array of `JobListEntry` objects of the specified length.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.list_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_jobs)
         """
 
     def list_long_term_pricing(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListLongTermPricingResultTypeDef:
         """
         Lists all long-term pricing types.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.list_long_term_pricing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.list_long_term_pricing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#list_long_term_pricing)
         """
 
@@ -367,20 +367,20 @@ class SnowballClient(BaseClient):
         self,
         *,
         ClusterId: str,
-        RoleARN: str = None,
-        Description: str = None,
-        Resources: "JobResourceTypeDef" = None,
-        OnDeviceServiceConfiguration: "OnDeviceServiceConfigurationTypeDef" = None,
-        AddressId: str = None,
-        ShippingOption: ShippingOptionType = None,
-        Notification: "NotificationTypeDef" = None,
-        ForwardingAddressId: str = None
+        RoleARN: str = ...,
+        Description: str = ...,
+        Resources: "JobResourceTypeDef" = ...,
+        OnDeviceServiceConfiguration: "OnDeviceServiceConfigurationTypeDef" = ...,
+        AddressId: str = ...,
+        ShippingOption: ShippingOptionType = ...,
+        Notification: "NotificationTypeDef" = ...,
+        ForwardingAddressId: str = ...
     ) -> Dict[str, Any]:
         """
         While a cluster's `ClusterState` value is in the `AwaitingQuorum` state, you can
         update some of the information associated with a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.update_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.update_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#update_cluster)
         """
 
@@ -388,21 +388,21 @@ class SnowballClient(BaseClient):
         self,
         *,
         JobId: str,
-        RoleARN: str = None,
-        Notification: "NotificationTypeDef" = None,
-        Resources: "JobResourceTypeDef" = None,
-        OnDeviceServiceConfiguration: "OnDeviceServiceConfigurationTypeDef" = None,
-        AddressId: str = None,
-        ShippingOption: ShippingOptionType = None,
-        Description: str = None,
-        SnowballCapacityPreference: SnowballCapacityType = None,
-        ForwardingAddressId: str = None
+        RoleARN: str = ...,
+        Notification: "NotificationTypeDef" = ...,
+        Resources: "JobResourceTypeDef" = ...,
+        OnDeviceServiceConfiguration: "OnDeviceServiceConfigurationTypeDef" = ...,
+        AddressId: str = ...,
+        ShippingOption: ShippingOptionType = ...,
+        Description: str = ...,
+        SnowballCapacityPreference: SnowballCapacityType = ...,
+        ForwardingAddressId: str = ...
     ) -> Dict[str, Any]:
         """
         While a job's `JobState` value is `New` , you can update some of the information
         associated with a job.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.update_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.update_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#update_job)
         """
 
@@ -412,7 +412,7 @@ class SnowballClient(BaseClient):
         """
         Updates the state when a shipment state changes to a different state.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.update_job_shipment_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.update_job_shipment_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#update_job_shipment_state)
         """
 
@@ -420,13 +420,13 @@ class SnowballClient(BaseClient):
         self,
         *,
         LongTermPricingId: str,
-        ReplacementJob: str = None,
-        IsLongTermPricingAutoRenew: bool = None
+        ReplacementJob: str = ...,
+        IsLongTermPricingAutoRenew: bool = ...
     ) -> Dict[str, Any]:
         """
         Updates the long-term pricing type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Client.update_long_term_pricing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Client.update_long_term_pricing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/client.html#update_long_term_pricing)
         """
 
@@ -435,7 +435,7 @@ class SnowballClient(BaseClient):
         self, operation_name: Literal["describe_addresses"]
     ) -> DescribeAddressesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.DescribeAddresses)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Paginator.DescribeAddresses)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#describeaddressespaginator)
         """
 
@@ -444,14 +444,14 @@ class SnowballClient(BaseClient):
         self, operation_name: Literal["list_cluster_jobs"]
     ) -> ListClusterJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.ListClusterJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Paginator.ListClusterJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#listclusterjobspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_clusters"]) -> ListClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.ListClusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Paginator.ListClusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#listclusterspaginator)
         """
 
@@ -460,13 +460,13 @@ class SnowballClient(BaseClient):
         self, operation_name: Literal["list_compatible_images"]
     ) -> ListCompatibleImagesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.ListCompatibleImages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Paginator.ListCompatibleImages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#listcompatibleimagespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_jobs"]) -> ListJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/snowball.html#Snowball.Paginator.ListJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.7/reference/services/snowball.html#Snowball.Paginator.ListJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_snowball/paginators.html#listjobspaginator)
         """
